toolforge_i18n documentation
============================

This section of the **toolforge_i18n** documentation is still incomplete.
Flask-based tools should look at :doc:`flask/index`;
some documentation for non-Flask-based tools will follow later.
You can also review the :doc:`api` at your convenience.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   flask/index
